Repositories

Struct Repositories 

pub struct Repositories {
    pub enabled: Option<bool>,
}
Configuration for enabling or disabling data repositories.

This structure is usually used to control whether repository layers backed by Redis or other data sources should be enabled.

Fields

enabled: Option<bool>

Enables or disables repositories.