setup

Function setup 

pub fn setup<F, P, Fut, PostFut>(init: F, post_init: P)
where F: FnOnce() -> Fut + Send + 'static, P: FnOnce() -> PostFut + Send + 'static, Fut: Future<Output = (Vec<Box<dyn Any + Send>>, Settings)> + Send + 'static, PostFut: Future<Output = ()> + Send + 'static,
Sets up the test environment by initializing the log, printing an ASCII art banner, and spawning a new thread that will execute the given closure.

The closure should return a Future that will be executed in a blocking context. The Future should complete before the test environment is considered initialized.

The test environment will wait for the setup signal to be sent before proceeding with the tests. After the setup signal is received, the test environment will wait for the shutdown signal before shutting down.

The shutdown signal is sent after all containers have been stopped and removed.