pub type Result<T, E = ServerError> = Result<T, E>;Expand description
A type alias for a Result with the ServerError error type.
Aliased Type
pub enum Result<T, E = ServerError> {
Ok(T),
Err(E),
}pub type Result<T, E = ServerError> = Result<T, E>;A type alias for a Result with the ServerError error type.
pub enum Result<T, E = ServerError> {
Ok(T),
Err(E),
}