pub async fn add_container(name: &str, id: String)Expand description
Adds a container to the container map.
This function takes a name and a container_id and inserts them into the container map.
The container map is a global, thread-safe map that stores container names as keys and container IDs as values.
This function returns no value, but it will block until the insertion is complete.